function [y] = make_1fnoise(x,gamma,h,fmin,fmax,Fs)


% Inputs
%  x		input signal
%  gamma	1/f^gamma parameter
%  h		number of poles per decade 
%		h = 1 gives about 5% accuracy, h = 1.5 about 1%
%  fmin         frequency of first pole (lowest frequency pole)
%  fmax         frequency of maximum pole (usually fmax < Fs/5)
%  Fs           fsample frequency
%  
% Reference
%   G. Corsini and R. Saletii, Design of a Digital 1/f^gamma Noise Simulator
%   


	%pole,zero locations
        log_freq = log10(fmin):(1/h):log10(fmax);
        freqpoles = 10.^(log_freq);
        numpoles =  length(freqpoles);
        freqzeros = freqpoles*10^(gamma/2/h);
    
        a = exp(-2*pi*freqpoles/Fs);
        b = exp(-2*pi*freqzeros/Fs);
        dcgain = prod([ones(numpoles,1)-b(:)] ./ [ones(numpoles,1)-a(:)]);
        
 
        y = x;

        for i = 1:length(freqpoles);
          y = filter([1 -b(i)],[1 -a(i)],y);
        end

        y = y/dcgain;
         



% Copyright (c) 1998 Thomas T. Liu

